[patch] Rename "prettyprint" to "prettyformat"

Doug Evans dje@google.com
Mon Jul 1 21:04:00 GMT 2013


Hi.
This patch is basically an internal renaming to remove some of the ambiguity in
"pretty printing".

The "prettyprinting" in struct value_print_options is now called
"prettyformatting".  The rest of the patch is just fallout from that.

Regression tested on amd64-linux.

I will check this in in a few days if there are no objections.

[I realize we had a discussion before about whether "All callers
updated." applies to just the one file, or all files.
There was no decision IIRC, and I prefer the simplicity of this way.]

2013-07-01  Doug Evans  <dje@google.com>

	* defs.h (enum val_prettyformat): Renamed from val_prettyprint.
	Enum values rename as well.  All uses updated.
	* valprint.h (value_print_options): Rename member pretty to
	pretty format.  Rename member prettyprint_arrays to
	prettyformat_arrays.  Rename member prettyprint_structs to
	prettyformat_structs.  All uses updated.
	(get_no_prettyformat_print_options): Renamed from
	get_raw_print_options.
	* valprint.c (get_no_prettyformat_print_options): Renamed from
	get_raw_print_options.  All callers updated.
	(show_prettyformat_structs): Renamed from show_prettyprint_structs.
	All callers updated.
	(show_prettyformat_arrays): Renamed from show_prettyprint_arrays.
	All callers updated.
	(_initialize_foo): Improve help text for "set print pretty" and
	"set print arrays".

	testsuite/
	gdb.base/default.exp: Update expected output of "show print array"
	and "show print pretty".

Index: ada-valprint.c
===================================================================
RCS file: /cvs/src/src/gdb/ada-valprint.c,v
retrieving revision 1.96
diff -u -p -r1.96 ada-valprint.c
--- ada-valprint.c	1 Feb 2013 20:08:45 -0000	1.96
+++ ada-valprint.c	1 Jul 2013 18:49:59 -0000
@@ -171,7 +171,7 @@ val_print_packed_array_elements (struct 
 
       if (i != 0)
 	{
-	  if (options->prettyprint_arrays)
+	  if (options->prettyformat_arrays)
 	    {
 	      fprintf_filtered (stream, ",\n");
 	      print_spaces_filtered (2 + 2 * recurse, stream);
@@ -227,7 +227,7 @@ val_print_packed_array_elements (struct 
 	    {
 	      if (j > i0)
 		{
-		  if (options->prettyprint_arrays)
+		  if (options->prettyformat_arrays)
 		    {
 		      fprintf_filtered (stream, ",\n");
 		      print_spaces_filtered (2 + 2 * recurse, stream);
@@ -600,7 +600,7 @@ ada_val_print_array (struct type *type, 
       eltlen = TYPE_LENGTH (elttype);
       len = TYPE_LENGTH (type) / eltlen;
 
-      if (options->prettyprint_arrays)
+      if (options->prettyformat_arrays)
         print_spaces_filtered (2 + 2 * recurse, stream);
 
       /* If requested, look for the first null char and only print
@@ -1001,7 +1001,7 @@ print_record (struct type *type, const g
 
   if (print_field_values (type, valaddr, offset,
 			  stream, recurse, val, options,
-			  0, type, offset) != 0 && options->pretty)
+			  0, type, offset) != 0 && options->prettyformat)
     {
       fprintf_filtered (stream, "\n");
       print_spaces_filtered (2 * recurse, stream);
@@ -1067,7 +1067,7 @@ print_field_values (struct type *type, c
 	fprintf_filtered (stream, ", ");
       comma_needed = 1;
 
-      if (options->pretty)
+      if (options->prettyformat)
 	{
 	  fprintf_filtered (stream, "\n");
 	  print_spaces_filtered (2 + 2 * recurse, stream);
Index: c-valprint.c
===================================================================
RCS file: /cvs/src/src/gdb/c-valprint.c,v
retrieving revision 1.103
diff -u -p -r1.103 c-valprint.c
--- c-valprint.c	22 May 2013 20:51:49 -0000	1.103
+++ c-valprint.c	1 Jul 2013 18:49:59 -0000
@@ -161,7 +161,7 @@ c_val_print (struct type *type, const gd
 
 	  eltlen = TYPE_LENGTH (elttype);
 	  len = high_bound - low_bound + 1;
-	  if (options->prettyprint_arrays)
+	  if (options->prettyformat_arrays)
 	    {
 	      print_spaces_filtered (2 + 2 * recurse, stream);
 	    }
@@ -353,7 +353,7 @@ c_val_print (struct type *type, const gd
 		  vt_val = value_at (wtype, vt_address);
 		  common_val_print (vt_val, stream, recurse + 1,
 				    options, current_language);
-		  if (options->pretty)
+		  if (options->prettyformat)
 		    {
 		      fprintf_filtered (stream, "\n");
 		      print_spaces_filtered (2 + 2 * recurse, stream);
Index: cp-valprint.c
===================================================================
RCS file: /cvs/src/src/gdb/cp-valprint.c,v
retrieving revision 1.90
diff -u -p -r1.90 cp-valprint.c
--- cp-valprint.c	19 Apr 2013 15:36:24 -0000	1.90
+++ cp-valprint.c	1 Jul 2013 18:49:59 -0000
@@ -239,7 +239,7 @@ cp_print_value_fields (struct type *type
 	    fprintf_filtered (stream, ", ");
 	  else if (n_baseclasses > 0)
 	    {
-	      if (options->pretty)
+	      if (options->prettyformat)
 		{
 		  fprintf_filtered (stream, "\n");
 		  print_spaces_filtered (2 + 2 * recurse, stream);
@@ -250,7 +250,7 @@ cp_print_value_fields (struct type *type
 	    }
 	  fields_seen = 1;
 
-	  if (options->pretty)
+	  if (options->prettyformat)
 	    {
 	      fprintf_filtered (stream, "\n");
 	      print_spaces_filtered (2 + 2 * recurse, stream);
@@ -407,7 +407,7 @@ cp_print_value_fields (struct type *type
 	    }
 	}
 
-      if (options->pretty)
+      if (options->prettyformat)
 	{
 	  fprintf_filtered (stream, "\n");
 	  print_spaces_filtered (2 * recurse, stream);
@@ -568,7 +568,7 @@ cp_print_value (struct type *type, struc
 	}
 
       /* Now do the printing.  */
-      if (options->pretty)
+      if (options->prettyformat)
 	{
 	  fprintf_filtered (stream, "\n");
 	  print_spaces_filtered (2 * recurse, stream);
Index: expprint.c
===================================================================
RCS file: /cvs/src/src/gdb/expprint.c,v
retrieving revision 1.68
diff -u -p -r1.68 expprint.c
--- expprint.c	15 Apr 2013 17:36:13 -0000	1.68
+++ expprint.c	1 Jul 2013 18:49:59 -0000
@@ -99,7 +99,7 @@ print_subexp_standard (struct expression
       {
 	struct value_print_options opts;
 
-	get_raw_print_options (&opts);
+	get_no_prettyformat_print_options (&opts);
 	(*pos) += 3;
 	value_print (value_from_longest (exp->elts[pc + 1].type,
 					 exp->elts[pc + 2].longconst),
@@ -111,7 +111,7 @@ print_subexp_standard (struct expression
       {
 	struct value_print_options opts;
 
-	get_raw_print_options (&opts);
+	get_no_prettyformat_print_options (&opts);
 	(*pos) += 3;
 	value_print (value_from_double (exp->elts[pc + 1].type,
 					exp->elts[pc + 2].doubleconst),
@@ -448,7 +448,7 @@ print_subexp_standard (struct expression
 	  (*pos) += 4;
 	  val = value_at_lazy (exp->elts[pc + 1].type,
 			       (CORE_ADDR) exp->elts[pc + 5].longconst);
-	  get_raw_print_options (&opts);
+	  get_no_prettyformat_print_options (&opts);
 	  value_print (val, stream, &opts);
 	}
       else
Index: infcmd.c
===================================================================
RCS file: /cvs/src/src/gdb/infcmd.c,v
retrieving revision 1.331
diff -u -p -r1.331 infcmd.c
--- infcmd.c	23 May 2013 17:15:34 -0000	1.331
+++ infcmd.c	1 Jul 2013 18:49:59 -0000
@@ -1506,7 +1506,7 @@ print_return_value (struct value *functi
       ui_out_field_fmt (uiout, "gdb-result-var", "$%d",
 			record_latest_value (value));
       ui_out_text (uiout, " = ");
-      get_raw_print_options (&opts);
+      get_no_prettyformat_print_options (&opts);
       value_print (value, stb, &opts);
       ui_out_field_stream (uiout, "return-value", stb);
       ui_out_text (uiout, "\n");
Index: jv-valprint.c
===================================================================
RCS file: /cvs/src/src/gdb/jv-valprint.c,v
retrieving revision 1.66
diff -u -p -r1.66 jv-valprint.c
--- jv-valprint.c	31 Jan 2013 18:37:37 -0000	1.66
+++ jv-valprint.c	1 Jul 2013 18:49:59 -0000
@@ -299,7 +299,7 @@ java_print_value_fields (struct type *ty
 
 	  boffset = 0;
 
-	  if (options->pretty)
+	  if (options->prettyformat)
 	    {
 	      fprintf_filtered (stream, "\n");
 	      print_spaces_filtered (2 * (recurse + 1), stream);
@@ -341,7 +341,7 @@ java_print_value_fields (struct type *ty
 	    fprintf_filtered (stream, ", ");
 	  else if (n_baseclasses > 0)
 	    {
-	      if (options->pretty)
+	      if (options->prettyformat)
 		{
 		  fprintf_filtered (stream, "\n");
 		  print_spaces_filtered (2 + 2 * recurse, stream);
@@ -352,7 +352,7 @@ java_print_value_fields (struct type *ty
 	    }
 	  fields_seen = 1;
 
-	  if (options->pretty)
+	  if (options->prettyformat)
 	    {
 	      fprintf_filtered (stream, "\n");
 	      print_spaces_filtered (2 + 2 * recurse, stream);
@@ -451,7 +451,7 @@ java_print_value_fields (struct type *ty
 	  annotate_field_end ();
 	}
 
-      if (options->pretty)
+      if (options->prettyformat)
 	{
 	  fprintf_filtered (stream, "\n");
 	  print_spaces_filtered (2 * recurse, stream);
Index: m2-valprint.c
===================================================================
RCS file: /cvs/src/src/gdb/m2-valprint.c,v
retrieving revision 1.47
diff -u -p -r1.47 m2-valprint.c
--- m2-valprint.c	1 Jan 2013 06:32:46 -0000	1.47
+++ m2-valprint.c	1 Jul 2013 18:49:59 -0000
@@ -272,7 +272,7 @@ m2_print_array_contents (struct type *ty
 
   if (TYPE_LENGTH (type) > 0)
     {
-      if (options->prettyprint_arrays)
+      if (options->prettyformat_arrays)
 	print_spaces_filtered (2 + 2 * recurse, stream);
       /* For an array of chars, print with string syntax.  */
       if (TYPE_LENGTH (type) == 1 &&
@@ -327,7 +327,7 @@ m2_val_print (struct type *type, const g
 	{
 	  elttype = check_typedef (TYPE_TARGET_TYPE (type));
 	  len = TYPE_LENGTH (type) / TYPE_LENGTH (elttype);
-	  if (options->prettyprint_arrays)
+	  if (options->prettyformat_arrays)
 	    print_spaces_filtered (2 + 2 * recurse, stream);
 	  /* For an array of chars, print with string syntax.  */
 	  if (TYPE_LENGTH (elttype) == 1 &&
Index: p-valprint.c
===================================================================
RCS file: /cvs/src/src/gdb/p-valprint.c,v
retrieving revision 1.106
diff -u -p -r1.106 p-valprint.c
--- p-valprint.c	8 Apr 2013 19:59:09 -0000	1.106
+++ p-valprint.c	1 Jul 2013 18:49:59 -0000
@@ -83,7 +83,7 @@ pascal_val_print (struct type *type, con
 	  len = high_bound - low_bound + 1;
 	  elttype = check_typedef (TYPE_TARGET_TYPE (type));
 	  eltlen = TYPE_LENGTH (elttype);
-	  if (options->prettyprint_arrays)
+	  if (options->prettyformat_arrays)
 	    {
 	      print_spaces_filtered (2 + 2 * recurse, stream);
 	    }
@@ -263,7 +263,7 @@ pascal_val_print (struct type *type, con
 	      vt_val = value_at (wtype, vt_address);
 	      common_val_print (vt_val, stream, recurse + 1, options,
 				current_language);
-	      if (options->pretty)
+	      if (options->prettyformat)
 		{
 		  fprintf_filtered (stream, "\n");
 		  print_spaces_filtered (2 + 2 * recurse, stream);
@@ -575,7 +575,7 @@ pascal_object_print_value_fields (struct
 	    fprintf_filtered (stream, ", ");
 	  else if (n_baseclasses > 0)
 	    {
-	      if (options->pretty)
+	      if (options->prettyformat)
 		{
 		  fprintf_filtered (stream, "\n");
 		  print_spaces_filtered (2 + 2 * recurse, stream);
@@ -586,7 +586,7 @@ pascal_object_print_value_fields (struct
 	    }
 	  fields_seen = 1;
 
-	  if (options->pretty)
+	  if (options->prettyformat)
 	    {
 	      fprintf_filtered (stream, "\n");
 	      print_spaces_filtered (2 + 2 * recurse, stream);
@@ -688,7 +688,7 @@ pascal_object_print_value_fields (struct
 	  dont_print_statmem_obstack = tmp_obstack;
 	}
 
-      if (options->pretty)
+      if (options->prettyformat)
 	{
 	  fprintf_filtered (stream, "\n");
 	  print_spaces_filtered (2 * recurse, stream);
@@ -787,7 +787,7 @@ pascal_object_print_value (struct type *
 	    base_valaddr = valaddr;
 	}
 
-      if (options->pretty)
+      if (options->prettyformat)
 	{
 	  fprintf_filtered (stream, "\n");
 	  print_spaces_filtered (2 * recurse, stream);
Index: stack.c
===================================================================
RCS file: /cvs/src/src/gdb/stack.c,v
retrieving revision 1.273
diff -u -p -r1.273 stack.c
--- stack.c	12 Jun 2013 12:16:47 -0000	1.273
+++ stack.c	1 Jul 2013 18:49:59 -0000
@@ -275,7 +275,7 @@ print_frame_arg (const struct frame_arg 
 	      else
 		language = current_language;
 
-	      get_raw_print_options (&opts);
+	      get_no_prettyformat_print_options (&opts);
 	      opts.deref_ref = 1;
 
 	      /* True in "summary" mode, false otherwise.  */
Index: valprint.c
===================================================================
RCS file: /cvs/src/src/gdb/valprint.c,v
retrieving revision 1.136
diff -u -p -r1.136 valprint.c
--- valprint.c	10 Apr 2013 15:11:11 -0000	1.136
+++ valprint.c	1 Jul 2013 18:49:59 -0000
@@ -104,9 +104,9 @@ void _initialize_valprint (void);
 
 struct value_print_options user_print_options =
 {
-  Val_pretty_default,		/* pretty */
-  0,				/* prettyprint_arrays */
-  0,				/* prettyprint_structs */
+  Val_prettyformat_default,	/* prettyformat */
+  0,				/* prettyformat_arrays */
+  0,				/* prettyformat_structs */
   0,				/* vtblprint */
   1,				/* unionprint */
   1,				/* addressprint */
@@ -133,12 +133,12 @@ get_user_print_options (struct value_pri
 }
 
 /* Initialize *OPTS to be a copy of the user print options, but with
-   pretty-printing disabled.  */
+   pretty-formatting disabled.  */
 void
-get_raw_print_options (struct value_print_options *opts)
+get_no_prettyformat_print_options (struct value_print_options *opts)
 {  
   *opts = user_print_options;
-  opts->pretty = Val_no_prettyprint;
+  opts->prettyformat = Val_no_prettyformat;
 }
 
 /* Initialize *OPTS to be a copy of the user print options, but using
@@ -221,19 +221,19 @@ show_stop_print_at_null (struct ui_file 
 /* Controls pretty printing of structures.  */
 
 static void
-show_prettyprint_structs (struct ui_file *file, int from_tty,
+show_prettyformat_structs (struct ui_file *file, int from_tty,
 			  struct cmd_list_element *c, const char *value)
 {
-  fprintf_filtered (file, _("Prettyprinting of structures is %s.\n"), value);
+  fprintf_filtered (file, _("Pretty formatting of structures is %s.\n"), value);
 }
 
 /* Controls pretty printing of arrays.  */
 
 static void
-show_prettyprint_arrays (struct ui_file *file, int from_tty,
+show_prettyformat_arrays (struct ui_file *file, int from_tty,
 			 struct cmd_list_element *c, const char *value)
 {
-  fprintf_filtered (file, _("Prettyprinting of arrays is %s.\n"), value);
+  fprintf_filtered (file, _("Pretty formatting of arrays is %s.\n"), value);
 }
 
 /* If nonzero, causes unions inside structures or other unions to be
@@ -390,7 +390,7 @@ generic_val_print (struct type *type, co
           if (!get_array_bounds (type, &low_bound, &high_bound))
             error (_("Could not determine the array high bound"));
 
-	  if (options->prettyprint_arrays)
+	  if (options->prettyformat_arrays)
 	    {
 	      print_spaces_filtered (2 + 2 * recurse, stream);
 	    }
@@ -736,9 +736,9 @@ val_print (struct type *type, const gdb_
   struct value_print_options local_opts = *options;
   struct type *real_type = check_typedef (type);
 
-  if (local_opts.pretty == Val_pretty_default)
-    local_opts.pretty = (local_opts.prettyprint_structs
-			 ? Val_prettyprint : Val_no_prettyprint);
+  if (local_opts.prettyformat == Val_prettyformat_default)
+    local_opts.prettyformat = (local_opts.prettyformat_structs
+			       ? Val_prettyformat : Val_no_prettyformat);
 
   QUIT;
 
@@ -1642,7 +1642,7 @@ val_print_array_elements (struct type *t
     {
       if (i != 0)
 	{
-	  if (options->prettyprint_arrays)
+	  if (options->prettyformat_arrays)
 	    {
 	      fprintf_filtered (stream, ",\n");
 	      print_spaces_filtered (2 + 2 * recurse, stream);
@@ -2730,11 +2730,11 @@ Show threshold for repeated print elemen
 			    &setprintlist, &showprintlist);
 
   add_setshow_boolean_cmd ("pretty", class_support,
-			   &user_print_options.prettyprint_structs, _("\
-Set prettyprinting of structures."), _("\
-Show prettyprinting of structures."), NULL,
+			   &user_print_options.prettyformat_structs, _("\
+Set pretty formatting of structures."), _("\
+Show pretty formatting of structures."), NULL,
 			   NULL,
-			   show_prettyprint_structs,
+			   show_prettyformat_structs,
 			   &setprintlist, &showprintlist);
 
   add_setshow_boolean_cmd ("union", class_support,
@@ -2746,11 +2746,11 @@ Show printing of unions interior to stru
 			   &setprintlist, &showprintlist);
 
   add_setshow_boolean_cmd ("array", class_support,
-			   &user_print_options.prettyprint_arrays, _("\
-Set prettyprinting of arrays."), _("\
-Show prettyprinting of arrays."), NULL,
+			   &user_print_options.prettyformat_arrays, _("\
+Set pretty formatting of arrays."), _("\
+Show pretty formatting of arrays."), NULL,
 			   NULL,
-			   show_prettyprint_arrays,
+			   show_prettyformat_arrays,
 			   &setprintlist, &showprintlist);
 
   add_setshow_boolean_cmd ("address", class_support,
Index: value.h
===================================================================
RCS file: /cvs/src/src/gdb/value.h,v
retrieving revision 1.220
diff -u -p -r1.220 value.h
--- value.h	28 Jun 2013 12:36:48 -0000	1.220
+++ value.h	1 Jul 2013 18:49:59 -0000
@@ -899,7 +899,7 @@ extern void value_print (struct value *v
 
 extern void value_print_array_elements (struct value *val,
 					struct ui_file *stream, int format,
-					enum val_prettyprint pretty);
+					enum val_prettyformat pretty);
 
 extern struct value *value_release_to_mark (struct value *mark);
 
Index: mi/mi-cmd-stack.c
===================================================================
RCS file: /cvs/src/src/gdb/mi/mi-cmd-stack.c,v
retrieving revision 1.70
diff -u -p -r1.70 mi-cmd-stack.c
--- mi/mi-cmd-stack.c	3 Jun 2013 03:16:24 -0000	1.70
+++ mi/mi-cmd-stack.c	1 Jul 2013 18:49:59 -0000
@@ -428,7 +428,7 @@ list_arg_or_local (const struct frame_ar
 	    {
 	      struct value_print_options opts;
 
-	      get_raw_print_options (&opts);
+	      get_no_prettyformat_print_options (&opts);
 	      opts.deref_ref = 1;
 	      common_val_print (arg->val, stb, 0, &opts,
 				language_def (SYMBOL_LANGUAGE (arg->sym)));
Index: mi/mi-main.c
===================================================================
RCS file: /cvs/src/src/gdb/mi/mi-main.c,v
retrieving revision 1.236
diff -u -p -r1.236 mi-main.c
--- mi/mi-main.c	26 Jun 2013 08:17:27 -0000	1.236
+++ mi/mi-main.c	1 Jul 2013 18:49:59 -0000
@@ -2627,7 +2627,7 @@ print_variable_or_computed (char *expres
 	{
 	  struct value_print_options opts;
 
-	  get_raw_print_options (&opts);
+	  get_no_prettyformat_print_options (&opts);
 	  opts.deref_ref = 1;
 	  common_val_print (val, stb, 0, &opts, current_language);
 	  ui_out_field_stream (uiout, "value", stb);
@@ -2637,7 +2637,7 @@ print_variable_or_computed (char *expres
       {
 	struct value_print_options opts;
 
-	get_raw_print_options (&opts);
+	get_no_prettyformat_print_options (&opts);
 	opts.deref_ref = 1;
 	common_val_print (val, stb, 0, &opts, current_language);
 	ui_out_field_stream (uiout, "value", stb);
Index: testsuite/gdb.base/default.exp
===================================================================
RCS file: /cvs/src/src/gdb/testsuite/gdb.base/default.exp,v
retrieving revision 1.66
diff -u -p -r1.66 default.exp
--- testsuite/gdb.base/default.exp	27 Jun 2013 18:49:03 -0000	1.66
+++ testsuite/gdb.base/default.exp	1 Jul 2013 18:49:59 -0000
@@ -667,7 +667,7 @@ gdb_test "show paths" "Executable and ob
 #test show print address
 gdb_test "show print address" "Printing of addresses is on." "show print address"
 #test show print array
-gdb_test "show print array" "Prettyprinting of arrays is on." "show print array"
+gdb_test "show print array" "Pretty formatting of arrays is on." "show print array"
 #test show print asm-demangle
 gdb_test "show print asm-demangle" "Demangling of C\[+\]+/ObjC names in disassembly listings is on." "show print asm-demangle"
 #test show print demangle
@@ -677,7 +677,7 @@ gdb_test "show print elements" "Limit on
 #test show print object
 gdb_test "show print object" "Printing of object's derived type based on vtable info is on." "show print object"
 #test show print pretty
-gdb_test "show print pretty" "Prettyprinting of structures is on." "show print pretty"
+gdb_test "show print pretty" "Pretty formatting of structures is on." "show print pretty"
 #test show print sevenbit-strings
 gdb_test "show print sevenbit-strings" "Printing of 8-bit characters in strings as .nnn is on." "show print sevenbit-strings"
 #test show print union



More information about the Gdb-patches mailing list
Index: defs.h
===================================================================
RCS file: /cvs/src/src/gdb/defs.h,v
retrieving revision 1.331
diff -u -p -r1.331 defs.h
--- defs.h	1 Jul 2013 11:28:30 -0000	1.331
+++ defs.h	1 Jul 2013 18:49:59 -0000
@@ -483,18 +483,18 @@ extern char *current_directory;
 extern unsigned input_radix;
 extern unsigned output_radix;
 
 /* Possibilities for prettyprint parameters to routines which print
    things.  Like enum language, this should be in value.h, but needs
    to be here for the same reason.  FIXME:  If we can eliminate this
    as an arg to LA_VAL_PRINT, then we can probably move it back to
    value.h.  */
 
-enum val_prettyprint
+enum val_prettyformat
   {
-    Val_no_prettyprint = 0,
-    Val_prettyprint,
+    Val_no_prettyformat = 0,
+    Val_prettyformat,
     /* Use the default setting which the user has specified.  */
-    Val_pretty_default
+    Val_prettyformat_default
   };
 
 /* Optional native machine support.  Non-native (and possibly pure
@@ -483,18 +483,18 @@ extern char *current_directory;
 extern unsigned output_radix;
 
-/* Possibilities for prettyprint parameters to routines which print
+/* Possibilities for prettyformat parameters to routines which print
    things.  Like enum language, this should be in value.h, but needs
    to be here for the same reason.  FIXME:  If we can eliminate this
Index: valprint.h
===================================================================
RCS file: /cvs/src/src/gdb/valprint.h,v
retrieving revision 1.46
diff -u -p -r1.46 valprint.h
--- valprint.h	13 Mar 2013 18:34:54 -0000	1.46
+++ valprint.h	1 Jul 2013 18:49:59 -0000
@@ -24,14 +24,14 @@
    functions.  */
 struct value_print_options
 {
-  /* Pretty-printing control.  */
-  enum val_prettyprint pretty;
+  /* Pretty-formatting control.  */
+  enum val_prettyformat prettyformat;
 
-  /* Controls pretty printing of arrays.  */
-  int prettyprint_arrays;
+  /* Controls pretty formatting of arrays.  */
+  int prettyformat_arrays;
 
-  /* Controls pretty printing of structures.  */
-  int prettyprint_structs;
+  /* Controls pretty formatting of structures.  */
+  int prettyformat_structs;
 
   /* Controls printing of virtual tables.  */
   int vtblprint;
@@ -101,8 +101,8 @@ extern struct value_print_options user_p
 extern void get_user_print_options (struct value_print_options *opts);
 
 /* Initialize *OPTS to be a copy of the user print options, but with
-   pretty-printing disabled.  */
-extern void get_raw_print_options (struct value_print_options *opts);
+   pretty-formatting disabled.  */
+extern void get_no_prettyformat_print_options (struct value_print_options *);
 
 /* Initialize *OPTS to be a copy of the user print options, but using
    FORMAT as the formatting option.  */
Index: python/py-prettyprint.c
===================================================================
RCS file: /cvs/src/src/gdb/python/py-prettyprint.c,v
retrieving revision 1.35
diff -u -p -r1.35 py-prettyprint.c
--- python/py-prettyprint.c	30 May 2013 17:17:25 -0000	1.35
+++ python/py-prettyprint.c	1 Jul 2013 18:49:59 -0000
@@ -511,16 +511,16 @@ print_children (PyObject *printer, const
     }
   make_cleanup_py_decref (iter);
 
   /* Use the prettyprint_arrays option if we are printing an array,
      and the pretty option otherwise.  */
   if (is_array)
-    pretty = options->prettyprint_arrays;
+    pretty = options->prettyformat_arrays;
   else
     {
-      if (options->pretty == Val_prettyprint)
+      if (options->prettyformat == Val_prettyformat)
 	pretty = 1;
       else
-	pretty = options->prettyprint_structs;
+	pretty = options->prettyformat_structs;
     }
 
   /* Manufacture a dummy Python frame to work around Python 2.4 bug,
@@ -511,16 +511,16 @@ print_children (PyObject *printer, const
   make_cleanup_py_decref (iter);
 
-  /* Use the prettyprint_arrays option if we are printing an array,
+  /* Use the prettyformat_arrays option if we are printing an array,
      and the pretty option otherwise.  */
   if (is_array)